summaryrefslogtreecommitdiffstats
path: root/kmail/configuredialog_p.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:21 -0600
commit86d8364ac704bdc8ad2dfcf52307d9626cfac567 (patch)
tree97d3ac2c2f60780d9a1de4f82caac7cb27534501 /kmail/configuredialog_p.h
parenta9bde819f2b421dcc44741156e75eca4bb5fb4f4 (diff)
downloadtdepim-86d8364ac704bdc8ad2dfcf52307d9626cfac567.tar.gz
tdepim-86d8364ac704bdc8ad2dfcf52307d9626cfac567.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kmail/configuredialog_p.h')
-rw-r--r--kmail/configuredialog_p.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/kmail/configuredialog_p.h b/kmail/configuredialog_p.h
index 0ed45d95..7b05ddb3 100644
--- a/kmail/configuredialog_p.h
+++ b/kmail/configuredialog_p.h
@@ -40,7 +40,7 @@ class ListView;
class ConfigureDialog;
class KIntSpinBox;
class SimpleStringListEditor;
-class KConfig;
+class TDEConfig;
class TQPoint;
class ComposerCryptoConfiguration;
class WarningConfiguration;
@@ -161,7 +161,7 @@ public:
ProfileDialog( TQWidget * parent=0, const char * name=0, bool modal=false );
signals:
- void profileSelected( KConfig * profile );
+ void profileSelected( TDEConfig * profile );
private slots:
void slotSelectionChanged();
@@ -176,12 +176,12 @@ private:
};
#include <kdialog.h>
-class ConfigModule : public KCModule {
+class ConfigModule : public TDECModule {
Q_OBJECT
public:
ConfigModule( TQWidget * parent=0, const char * name=0 )
- : KCModule ( parent, name )
+ : TDECModule ( parent, name )
{}
~ConfigModule() {}
@@ -198,7 +198,7 @@ signals:
from the profile only for those entries that
really have keys defined in the profile.
*/
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
};
@@ -230,7 +230,7 @@ private:
// via GlobalSettings
virtual void doLoadOther() {}
// reimplement this for loading default values of settings which are
// not available via GlobalSettings (KConfigXT).
virtual void doResetToDefaultsOther() {}
};
@@ -250,7 +250,7 @@ public:
virtual void load();
virtual void save();
virtual void defaults();
- virtual void installProfile( KConfig * profile );
+ virtual void installProfile( TDEConfig * profile );
protected:
void addTab( ConfigModuleTab* tab, const TQString & title );
@@ -437,7 +437,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private slots:
void slotFontSelectorChanged( int );
@@ -465,7 +465,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private:
//virtual void doLoadFromGlobalSettings();
@@ -487,7 +487,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private:
//virtual void doLoadFromGlobalSettings();
@@ -511,7 +511,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private: // methods
//virtual void doLoadFromGlobalSettings();
@@ -538,7 +538,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private:
virtual void doLoadFromGlobalSettings();
@@ -570,7 +570,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private:
virtual void doLoadFromGlobalSettings();
@@ -619,7 +619,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
protected slots:
void slotConfigureRecentAddresses();
void slotConfigureCompletionOrder();
@@ -852,7 +852,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private:
//virtual void doLoadFromGlobalSettings();
@@ -879,7 +879,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private:
//virtual void doLoadFromGlobalSettings();
@@ -899,7 +899,7 @@ public:
TQString helpAnchor() const;
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private slots:
void slotReenableAllWarningsClicked();
@@ -925,7 +925,7 @@ public:
// Can't use k_dcop here. dcopidl can't parse this file, dcopidlng has a namespace bug.
void save();
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
private slots:
void slotUpdateHTTPActions();
@@ -969,7 +969,7 @@ public:
TQString helpAnchor() const;
// OpenPGP tab is special:
- void installProfile( KConfig * profile );
+ void installProfile( TDEConfig * profile );
typedef SecurityPageGeneralTab GeneralTab;
typedef SecurityPageComposerCryptoTab ComposerCryptoTab;
@@ -230,7 +230,7 @@ private:
virtual void doLoadOther() {}
// reimplement this for loading default values of settings which are
- // not available via GlobalSettings (KConfigXT).
+ // not available via GlobalSettings (TDEConfigXT).
virtual void doResetToDefaultsOther() {}
};